==> uix-kit-4.2.0.tgz: package/CONTRIBUTING.md <==
# Contributing to Uix Kit

Hi, there!

* [Communication](#communication)
* [Resources](#res)
* [License](#license)

<a name="communication"></a>
## Communication

* Website: https://uiux.cc
* Twitter: https://twitter.com/uiux_lab


<a name="res"></a>
## Resources

Uix Kit bundles the following third-party resources:

- [jQuery](https://jquery.com/)
- [Font Awesome](http://fontawesome.io)
- [Flexslider](https://github.com/woocommerce/FlexSlider)
- [Bootstrap v4](http://getbootstrap.com)
- [waitForImages](https://github.com/alexanderdickson/waitForImages)
- [modernizr](https://modernizr.com/)
- [animejs](https://github.com/juliangarnier/anime)
- [Video.js](https://github.com/videojs)
- [prefixfree](https://github.com/LeaVerou/prefixfree)
- [template7](http://www.idangero.us/template7/)
- [pixi](https://github.com/GoodBoyDigital/pixi.js)
- [GSAP - Standard "No Charge" GreenSock License](https://greensock.com)
- [three.js](https://github.com/mrdoob/three.js/)
- [Hammer.JS](http://hammerjs.github.io/)
- [Muuri](https://github.com/haltu/muuri)
- [axios](https://github.com/axios/axios)





All photos uploaded to the site are released under Creative Commons - CC0 and do not require attribution. No more hassle trying to figure out whether you can use photos for commercial use and whether you need to provide attribution. (http://www.gratisography.com, https://stocksnap.io ) Part of the image and videos used in the demo are not distributed with the theme. They are all licensed under Creative Commons and credited to their respective creator/owner.





<a name="license"></a>
## License

By contributing your code, you agree to license your contribution under the [MIT license](LICENSE)

==> uix-kit-4.4.9.tgz: package/CONTRIBUTING.md <==
# Contributing to Uix Kit

Hi, there!

* [Communication](#communication)
* [Resources](#res)
* [License](#license)

<a name="communication"></a>
## Communication

* Website: https://uiux.cc
* Twitter: https://twitter.com/uiux_lab


<a name="res"></a>
## Resources

Uix Kit bundles the following third-party resources:

- [jQuery](https://jquery.com/)
- [Font Awesome](http://fontawesome.io)
- [Bootstrap](http://getbootstrap.com)
- [waitForImages](https://github.com/alexanderdickson/waitForImages)
- [modernizr](https://modernizr.com/)
- [animejs](https://github.com/juliangarnier/anime)
- [Video.js](https://github.com/videojs)
- [prefixfree](https://github.com/LeaVerou/prefixfree)
- [template7](http://www.idangero.us/template7/)
- [pixi](https://github.com/GoodBoyDigital/pixi.js)
- [GSAP - Standard "No Charge" GreenSock License](https://greensock.com)
- [three.js](https://github.com/mrdoob/three.js/)
- [Hammer.JS](http://hammerjs.github.io/)
- [Muuri](https://github.com/haltu/muuri)
- [axios](https://github.com/axios/axios)





All photos uploaded to the site are released under Creative Commons - CC0 and do not require attribution. No more hassle trying to figure out whether you can use photos for commercial use and whether you need to provide attribution. (http://www.gratisography.com, https://stocksnap.io ) Part of the image and videos used in the demo are not distributed with the theme. They are all licensed under Creative Commons and credited to their respective creator/owner.





<a name="license"></a>
## License

By contributing your code, you agree to license your contribution under the [MIT license](LICENSE)
